from .cnb_exchange_rate import monthly_average
from .cnb_exchange_rate import cumulative_monthly_average
from .cnb_exchange_rate import quarterly_average
from .cnb_exchange_rate import daily_rate
from .cnb_exchange_rate import set_host
